/**
 * Copyright 2012-2016 Craig Campbell
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Rainbow is a simple code syntax highlighter
 *
 * @see rainbowco.de
 */
import { Pattern } from './prism.js';
declare global {
    interface ImportMeta {
        url: string;
    }
}
/**
 * Callback to let you do stuff in your app after a piece of code has
 * been highlighted
 */
export declare function onHighlight(callback: Function): void;
/**
 * Extends the language pattern matches
 *
 * @param language            name of language
 * @param languagePatterns    object of patterns to add on
 * @param inherits  optional language that this language
 *                                     should inherit rules from
 */
export declare function extend(language: string, languagePatterns: Pattern[], inherits?: string): void;
export declare function remove(language: string): void;
declare type ColorResult = {
    result: string;
    lang: string;
};
/**
 * Starts the magic rainbow
 */
export declare function color(): Promise<void>;
export declare function color(element: Element | ShadowRoot): Promise<void>;
export declare function color(code: string, language: string): Promise<ColorResult>;
/**
 * Method to add an alias for an existing language.
 *
 * For example if you want to have "coffee" map to "coffeescript"
 *
 * @see https://github.com/ccampbell/rainbow/issues/154
 * @return {void}
 */
export declare function addAlias(alias: string, originalLanguage: string): void;
export {};
